==> everycomp-1.20-2.9.9-fabric-sources.jar: net/mehvahdjukaar/every_compat/modules/botanypots/BotanyPotsHelper.java <==
package net.mehvahdjukaar.every_compat.modules.botanypots;

import com.google.gson.JsonObject;
import net.mehvahdjukaar.every_compat.EveryCompat;
import net.mehvahdjukaar.every_compat.modules.quark.QuarkModule;
import net.mehvahdjukaar.moonlight.api.resources.RPUtils;
import net.mehvahdjukaar.moonlight.api.resources.ResType;
import net.mehvahdjukaar.moonlight.api.resources.pack.ResourceSink;
import net.mehvahdjukaar.moonlight.api.set.leaves.LeavesType;
import net.mehvahdjukaar.moonlight.api.util.Utils;
import net.minecraft.class_1792;
import net.minecraft.class_2960;
import net.minecraft.class_3300;
import java.io.InputStream;

public class BotanyPotsHelper {

    public static void cropQuarkHedgeRecipe(QuarkModule module, class_1792 input, class_1792 output, ResourceSink handler, class_3300 manager, LeavesType leaves) {

        class_2960 recipeLocation = EveryCompat.res("template_recipes/botanypots/crop/leaves_from_quark_hedge_crop.json"); // get Recipe JSON
        JsonObject recipe = null;

        try (InputStream recipeStream = manager.method_14486(recipeLocation).orElseThrow().method_14482()) {
            recipe = RPUtils.deserializeJson(recipeStream);

            JsonObject getSeed = recipe.getAsJsonObject("seed");
            getSeed.addProperty("item", Utils.getID(input).toString());

            JsonObject getDisplay = recipe.getAsJsonObject("display");
            getDisplay.addProperty("block", Utils.getID(input).toString());

            JsonObject getDrops = recipe.getAsJsonArray("drops").get(0).getAsJsonObject().getAsJsonObject("output");
            getDrops.addProperty("item", Utils.getID(output).toString());

        } catch (Exception e) {
            EveryCompat.LOGGER.error("{BotanyPots Helper} crop_quarkhedge_recipe(): {}", String.valueOf(e));
        }

        String filenameBuilder = "_from_quark_hedge_crop";
        handler.addJson(EveryCompat.res(module.shortenedId() + "/" + leaves.getAppendableId() + filenameBuilder), recipe, ResType.RECIPES);
    }
}

==> everycomp-1.21-2.11.9-fabric-sources.jar: net/mehvahdjukaar/every_compat/modules/botanypots/BotanyPotsHelper.java <==
package net.mehvahdjukaar.every_compat.modules.botanypots;

import com.google.gson.JsonObject;
import net.mehvahdjukaar.every_compat.EveryCompat;
import net.mehvahdjukaar.every_compat.modules.quark.QuarkModule;
import net.mehvahdjukaar.moonlight.api.resources.RPUtils;
import net.mehvahdjukaar.moonlight.api.resources.ResType;
import net.mehvahdjukaar.moonlight.api.resources.pack.ResourceSink;
import net.mehvahdjukaar.moonlight.api.set.leaves.LeavesType;
import net.mehvahdjukaar.moonlight.api.util.Utils;
import net.minecraft.class_1792;
import net.minecraft.class_2960;
import net.minecraft.class_3300;
import java.io.InputStream;

public class BotanyPotsHelper {

    public static void cropQuarkHedgeRecipe(QuarkModule module, class_1792 input, class_1792 output, ResourceSink sink, class_3300 manager, LeavesType leaves) {

        class_2960 recipeLocation = EveryCompat.res("template_recipes/botanypots/crop/leaves_from_quark_hedge_crop.json"); // get Recipe JSON
        JsonObject recipe = null;

        try (InputStream recipeStream = manager.method_14486(recipeLocation).orElseThrow().method_14482()) {
            recipe = RPUtils.deserializeJson(recipeStream);

            JsonObject getSeed = recipe.getAsJsonObject("seed");
            getSeed.addProperty("item", Utils.getID(input).toString());

            JsonObject getDisplay = recipe.getAsJsonObject("display");
            getDisplay.addProperty("block", Utils.getID(input).toString());

            JsonObject getDrops = recipe.getAsJsonArray("drops").get(0).getAsJsonObject().getAsJsonObject("output");
            getDrops.addProperty("item", Utils.getID(output).toString());

        } catch (Exception e) {
            EveryCompat.LOGGER.error("{BotanyPots Helper} crop_quarkhedge_recipe(): {}", String.valueOf(e));
        }

        String filenameBuilder = "_from_quark_hedge_crop";
        sink.addJson(EveryCompat.res(module.shortenedId() + "/" + leaves.getAppendableId() + filenameBuilder), recipe, ResType.RECIPES);
    }
}
